<?php
session_start();
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'admin') {
    header('Location: ../auth/login.php');
    exit();
}

require_once '../config/koneksi.php';

// Cek apakah parameter 'id' ada di URL
if (!isset($_GET['id'])) {
    header('Location: ../admin');
    exit();
}

$blogId = $_GET['id'];

// Ambil data blog berdasarkan ID
$stmt = $pdo->prepare("SELECT * FROM blogs WHERE id = :id");
$stmt->execute(['id' => $blogId]);
$blog = $stmt->fetch();

if (!$blog) {
    header('Location: ../admin');
    exit();
}

// Proses update blog
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Ambil data dari form
    $title = $_POST['title'];
    $content = $_POST['content'];

    // Update data blog di database
    $updateStmt = $pdo->prepare("UPDATE blogs SET title = :title, content = :content WHERE id = :id");
    $updateStmt->execute([
        'title' => $title,
        'content' => $content,
        'id' => $blogId
    ]);

    // Redirect setelah berhasil update
    header("Location: ../admin");
    exit();
}
?>

<!DOCTYPE html>
<html lang="id">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Blog - FixPonsel</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://fonts.googleapis.com/css2?family=Orbitron:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="../assets/css/style.css">
</head>
<body class="bg-dark text-light">
    <?php include('../includes/navbar.php'); ?>

    <div class="container mt-5">
        <h1 class="text-center">Edit Blog</h1>

        <!-- Form untuk mengedit blog -->
        <form method="POST">
            <div class="mb-3">
                <label for="title" class="form-label">Judul Blog</label>
                <input type="text" class="form-control" id="title" name="title" value="<?php echo htmlspecialchars($blog['title']); ?>" required>
            </div>
            <div class="mb-3">
                <label for="content" class="form-label">Isi Blog</label>
                <textarea class="form-control" id="content" name="content" rows="5" required><?php echo htmlspecialchars($blog['content']); ?></textarea>
            </div>
            <button type="submit" class="btn btn-primary w-100">Update Blog</button>
        </form>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>